@@ -11,7 +11,7 @@ pub struct AttributesArgs {
   #[darling(multiple)]
   pub crab: Vec<syn::Meta>,
   #[darling(multiple)]
-  pub client: Vec<syn::Meta>
+  pub client: Vec<syn::Meta>,
 }
 
 #[derive(Debug, FromMeta)]
@@ -20,5 +20,5 @@ pub struct Args {
   pub on: Option<syn::Ident>,
   pub crab: syn::Path,
   #[darling(default)]
-  pub attributes: Option<AttributesArgs>
+  pub attributes: Option<AttributesArgs>,
 }
